@@ -13,7 +13,7 @@ extensions = [
     'sphinx.ext.coverage',
     'sphinx.ext.ifconfig',
     'sphinx.ext.viewcode',
-    'sphinxcontrib.napoleon',
+    'numpydoc',
     'sphinx.ext.intersphinx',
 ]
 
@@ -73,16 +73,7 @@ version = '.'.join(split_version)
 add_function_parentheses = False
 pygments_style = 'sphinx'
 
-napoleon_google_docstring = False
-napoleon_numpy_docstring = True
-napoleon_include_private_with_doc = False
-napoleon_include_special_with_doc = False
-napoleon_use_admonition_for_examples = False
-napoleon_use_admonition_for_notes = False
-napoleon_use_admonition_for_references = False
-napoleon_use_ivar = False
-napoleon_use_param = True
-napoleon_use_rtype = True
+numpydoc_show_class_members = False
 
 intersphinx_mapping = {
     'numpy': ('http://docs.scipy.org/doc/numpy/', None),
@@ -95,12 +86,12 @@ rst_epilog = """
 .. |Polygon| replace:: :class:`Polygon3.Polygon`
 .. |array| replace:: :class:`array <numpy.ndarray>`
 
-.. |Shape| replace:: :class:`Shape`
-.. |Shape.circle| replace:: :meth:`Shape.circle`
-.. |Shape.rectangle| replace:: :meth:`Shape.rectangle`
-.. |Shape.regular_polygon| replace:: :meth:`Shape.regular_polygon`
-.. |Shape.from_dict| replace:: :meth:`Shape.from_dict`
-.. |Shape.scale| replace:: :meth:`Shape.scale`
-.. |Shape.translate| replace:: :meth:`Shape.translate`
+.. |Shape| replace:: :class:`~pyglet2d.Shape`
+.. |Shape.circle| replace:: :meth:`~pyglet2d.Shape.circle`
+.. |Shape.rectangle| replace:: :meth:`~pyglet2d.Shape.rectangle`
+.. |Shape.regular_polygon| replace:: :meth:`~pyglet2d.Shape.regular_polygon`
+.. |Shape.from_dict| replace:: :meth:`~pyglet2d.Shape.from_dict`
+.. |Shape.scale| replace:: :meth:`~pyglet2d.Shape.scale`
+.. |Shape.translate| replace:: :meth:`~pyglet2d.Shape.translate`
 
 """
